@@ -764,7 +764,6 @@ class Update(MethodsInterface):
                 _("Listing packages for removal")))
             self._display_pretty_package_list(pkglist, remove_list=True)
 
-
     def mark_schedule(self):
         """
         Установить отметку о запуске запланированной проверки
@@ -772,7 +771,11 @@ class Update(MethodsInterface):
         SystemIni(self.clVars).setVar('system', {'last_check': str(int(time.time()))})
 
     def get_default_emerge_opts(self):
-        return self.clVars.Get('cl_emerge_default_opts')
+        if self.clVars.GetBool('cl_update_with_bdeps_set'):
+            bdeps = " --with-bdeps=y"
+        else:
+            bdeps = " --with-bdeps=n"
+        return self.clVars.Get('cl_emerge_default_opts') + bdeps
 
     def premerge(self, param, *packages):
         """
@@ -1219,6 +1222,14 @@ class Update(MethodsInterface):
                     location="system")
         return True
 
+    def save_with_bdeps(self):
+        oldval = self.clVars.Get('cl_update_with_bdeps_set')
+        newval = self.clVars.Get('cl_update_with_bdeps_opt_set')
+        if oldval != newval:
+            self.clVars.Write('cl_update_with_bdeps_set', newval,
+                              location="system")
+        return True
+
     def message_binhost_changed(self):
         if self.refresh_binhost:
             self.printWARNING(_("Update server was changed to %s") %
