@@ -71,6 +71,10 @@ class ClUpdateAction(Action):
     interruptMessage = __("Update manually interrupted")
 
     emerge_tasks = [
+        {'name': 'save_bdeps_val',
+         'method': 'Update.save_with_bdeps()',
+         'essential': False
+         },
         {'name': 'premerge_group',
          'group': __("Checking for updates"),
          'tasks': [
