@@ -1729,3 +1729,26 @@ class VariableClUpdatePackageCacheSet(Variable):
         except ValueError:
             return "on"
         return "on"
+
+
+class VariableClUpdateWithBdepsSet(Variable):
+    """
+    Добавление --with-bdeps при вызове emerge
+    """
+    type = "bool"
+    value = "off"
+
+
+class VariableClUpdateWithBdepsOptSet(Variable):
+    """
+    Добавление --with-bdeps при вызове emerge (опция)
+    """
+    type = "bool"
+    opt = ["--with-bdeps"]
+
+    def init(self):
+        self.help = _("Save packages used during build")
+        self.label = _("save packages used during build")
+
+    def get(self):
+        return self.Get('cl_update_with_bdeps_set')
